# Contributing

When contributing to this repository, please first discuss the change you wish to make via an issue, 
with the owners of this repository before making a change. You can open an issue [here](https://github.com/Codebrahma/react-lite-ui/issues).

Please note we have a code of conduct, please follow it in all your interactions with the project. You can find it [here](https://github.com/Codebrahma/react-lite-ui/blob/master/CODE_OF_CONDUCT.md).

## Pull Request Process

1. Ensure that all external dependencies not required for the build / development flow are removed
before build.
2. Update the documentation for the component ( if applicable ).
3. Ensure all tests are passing and are above the coverage threshold.
4. Your Pull Request can be merged in once you have the sign-off of atleast one other developer. If you find that your
Pull Request has been approved and not been merged, you can ask the reviewer to merge it. Incase there has been no activity
on your pull request : 
    * Ensure there is an issue open which is related to the request. Pull requests without any related issues will not be processed.
    * Check for activity in other issues / pull requests related to your pull request.

## Getting Started

To run the project locally, you can : 

1. Clone the repository :

via SSH :
```
git clone git@github.com:Codebrahma/react-lite-ui.git
```

**or**

via HTTPS: 
```
git clone https://github.com/Codebrahma/react-lite-ui.git
```

2. Install dependencies from `package.json` : 

```
npm install && cd doc && npm install
```


3. To run the documentation page in your local server : 
```
npm run docs:dev
```

**Note :** If you are willing to contribute to the project, then you can fork the repository and raise a Pull Request from 
the fork.

### Adding features / functionalities :

If you want to add a new feature to the existing set of functionalities, we recommend you to
first discuss with the repository maintainers by opening an issue [here](https://github.com/Codebrahma/react-lite-ui/issues).
Please note that we may add a suggested feature only if it adds value to our [purpose](#purpose-) of this project.

#### Notes on adding new functionalities :

After adding a new feature, please go through the following :

1. Proper tests for the new features have been added and are passing.
2. All the tests should pass.
3. Documentation has been updated with new features and instructions of their usage.

## Purpose :

The purpose of this project is to provide a component library and ultimately a UI kit that is
easier to customise, lightweight and easy to use than any other popular libraries are / have been able to provide.
The focus is on keeping the components as minimal as possible while providing various options to
customise which might generally be required in a scalable production code and can decrease the overhead of 
complicated configurations, code styles or other requirements.


## Code of Conduct

Our team is dedicated towards creating and maintaining an ethical, responsible and positive environment for the community.
Please go through our [code of conduct](https://github.com/Codebrahma/react-lite-ui/blob/master/CODE_OF_CONDUCT.md) to read about some of the ways in which we can maintain proper communication.
